@@ -13,7 +13,7 @@ use Exporter ();
 
 use Validation::Class::Prototype;
 
-our $VERSION = '7.900032'; # VERSION
+our $VERSION = '7.900033'; # VERSION
 
 our @ISA    = qw(Exporter);
 our @EXPORT = qw(
@@ -195,7 +195,7 @@ sub initialize_validator {
 
     # initialize prototype
 
-    $proto->normalize;
+    $proto->normalize($self);
 
     # ready-set-go !!!
 
@@ -508,6 +508,7 @@ sub proto { goto &prototype } sub prototype {
 1;
 
 __END__
+
 =pod
 
 =head1 NAME
@@ -516,7 +517,7 @@ Validation::Class - Powerful Data Validation Framework
 
 =head1 VERSION
 
-version 7.900032
+version 7.900033
 
 =head1 SYNOPSIS
 
@@ -1411,4 +1412,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
